package twisk.modele;

import twisk.exceptions.ParametresException;
import twisk.outils.TailleComposants;

public class ActiviteIG extends EtapeIG {
    private int delai;
    private int ecart;

    /**
     * Constructeur
     * @param nom le nom de l'activité
     */
    public ActiviteIG(String nom) {
        // Utilisation des tailles définies dans TailleComposants
        super(nom, TailleComposants.getInstance().getLargeurActivite(),
                TailleComposants.getInstance().getHauteurActivite());

        // Initialiser les paramètres avec des valeurs par défaut
        this.delai = 4; // Valeur par défaut pour le délai
        this.ecart = 2; // Valeur par défaut pour l'écart
    }

    /**
     * Définit le délai de l'activité
     * @param delai le délai en unités de temps
     * @throws ParametresException si le délai est négatif ou nul
     */
    public void setDelai(int delai) throws ParametresException {
        if (delai <= 0) {
            throw new ParametresException("Le délai doit être un nombre positif");
        }
        this.delai = delai;
    }

    /**
     * Définit l'écart de l'activité
     * @param ecart l'écart en unités de temps
     * @throws ParametresException si l'écart est négatif ou supérieur au délai
     */
    public void setEcart(int ecart) throws ParametresException {
        if (ecart < 0) {
            throw new ParametresException("L'écart doit être un nombre positif ou nul");
        }
        if (ecart >= delai) {
            throw new ParametresException("L'écart doit être inférieur au délai");
        }
        this.ecart = ecart;
    }

    /**
     * Retourne le délai de l'activité
     * @return le délai
     */
    public int getDelai() {
        return delai;
    }

    /**
     * Retourne l'écart de l'activité
     * @return l'écart
     */
    public int getEcart() {
        return ecart;
    }
}
