package twisk.modele;

/**
 * Classe abstraite représentant un arc dans l'interface graphique
 */
public abstract class ArcIG {
    protected final PointDeControleIG p1;
    protected final PointDeControleIG p2;
    protected final String id;

    /**
     * Constructeur
     * @param p1 premier point de contrôle
     * @param p2 deuxième point de contrôle
     */
    public ArcIG(PointDeControleIG p1, PointDeControleIG p2) {
        this.p1 = p1;
        this.p2 = p2;
        this.id = FabriqueIdentifiant.getInstance().getIdentifiantUnique();
    }

    /**
     * Retourne le premier point de contrôle
     * @return premier point de contrôle
     */
    public PointDeControleIG getP1() {
        return p1;
    }

    /**
     * Retourne le deuxième point de contrôle
     * @return deuxième point de contrôle
     */
    public PointDeControleIG getP2() {
        return p2;
    }

    /**
     * Retourne l'identifiant de l'arc
     * @return identifiant
     */
    public String getId() {
        return id;
    }
}
