package twisk.modele;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public abstract class EtapeIG implements Iterable<PointDeControleIG> {
    protected String nom;
    protected String identifiant;
    protected int posX;
    protected int posY;
    protected int largeur;
    protected int hauteur;
    protected List<PointDeControleIG> pointsDeControle;

    public EtapeIG(String nom, int largeur, int hauteur) {
        this.nom = nom;
        this.identifiant = FabriqueIdentifiant.getInstance().getIdentifiantUnique();
        // Position aléatoire entre 0 et 500 (à ajuster selon vos besoins)
        this.posX = (int) (Math.random() * 500);
        this.posY = (int) (Math.random() * 500);
        this.largeur = largeur;
        this.hauteur = hauteur;

        // Initialisation de la liste des points de contrôle
        this.pointsDeControle = new ArrayList<>(4);

        // Création des 4 points de contrôle (un au milieu de chaque côté)
        creerPointsDeControle();
    }

    /**
     * Crée les 4 points de contrôle pour l'étape
     */
    private void creerPointsDeControle() {
        // Point sur le côté supérieur (milieu)
        pointsDeControle.add(new PointDeControleIG(
                "p" + identifiant + "N", // N pour Nord
                this,
                "N"
        ));

        // Point sur le côté droit (milieu)
        pointsDeControle.add(new PointDeControleIG(
                "p" + identifiant + "E", // E pour Est
                this,
                "E"
        ));

        // Point sur le côté inférieur (milieu)
        pointsDeControle.add(new PointDeControleIG(
                "p" + identifiant + "S", // S pour Sud
                this,
                "S"
        ));

        // Point sur le côté gauche (milieu)
        pointsDeControle.add(new PointDeControleIG(
                "p" + identifiant + "O", // O pour Ouest
                this,
                "O"
        ));
    }
    /**
     * Met à jour la position des points de contrôle quand l'étape est déplacée
     */
    public void majPointsDeControle() {
        // Vider la liste actuelle
        pointsDeControle.clear();

        // Recréer les points de contrôle avec les nouvelles coordonnées
        creerPointsDeControle();
    }

    // Implémentation de l'interface Iterable
    @Override
    public Iterator<PointDeControleIG> iterator() {
        return pointsDeControle.iterator();
    }

    // Getters et setters existants
    public String getNom() {
        return nom;
    }

    public void setNom(String nom) {
        this.nom = nom;
    }

    public String getIdentifiant() {
        return identifiant;
    }

    public int getPosX() {
        return posX;
    }

    public void setPosX(int posX) {
        this.posX = posX;
        // Mettre à jour les points de contrôle
        majPointsDeControle();
    }

    public int getPosY() {
        return posY;
    }

    public void setPosY(int posY) {
        this.posY = posY;
        // Mettre à jour les points de contrôle
        majPointsDeControle();
    }

    public int getLargeur() {
        return largeur;
    }

    public void setLargeur(int largeur) {
        this.largeur = largeur;
        // Mettre à jour les points de contrôle
        majPointsDeControle();
    }

    public int getHauteur() {
        return hauteur;
    }

    public void setHauteur(int hauteur) {
        this.hauteur = hauteur;
        // Mettre à jour les points de contrôle
        majPointsDeControle();
    }
}
