package twisk.modele;

/**
 * Classe représentant un point de contrôle sur une étape
 */
public class PointDeControleIG {
    private final String id;
    private final EtapeIG etape;
    private final String position; // "N", "E", "S", "O"

    /**
     * Constructeur
     * @param id identifiant du point
     * @param etape étape à laquelle appartient le point
     * @param position position du point ("N", "E", "S", "O")
     */
    public PointDeControleIG(String id, EtapeIG etape, String position) {
        this.id = id;
        this.etape = etape;
        this.position = position;
    }

    /**
     * Retourne la coordonnée X du point
     * @return coordonnée X
     */
    public int getPosX() {
        switch (position) {
            case "N": // Nord
            case "S": // Sud
                return etape.getPosX() + etape.getLargeur() / 2;
            case "E": // Est
                return etape.getPosX() + etape.getLargeur();
            case "O": // Ouest
                return etape.getPosX();
            default:
                return 0;
        }
    }

    /**
     * Retourne la coordonnée Y du point
     * @return coordonnée Y
     */
    public int getPosY() {
        switch (position) {
            case "N": // Nord
                return etape.getPosY();
            case "E": // Est
            case "O": // Ouest
                return etape.getPosY() + etape.getHauteur() / 2;
            case "S": // Sud
                return etape.getPosY() + etape.getHauteur();
            default:
                return 0;
        }
    }

    /**
     * Retourne l'identifiant du point
     * @return identifiant
     */
    public String getId() {
        return id;
    }

    /**
     * Retourne l'étape à laquelle le point est rattaché
     * @return étape
     */
    public EtapeIG getEtape() {
        return etape;
    }
}
