package twisk.outils;

/**
 * Classe singleton qui centralise les constantes de taille des composants graphiques
 */
public class TailleComposants {
    private static TailleComposants instance = new TailleComposants();

    // Tailles pour les activités
    private final int largeurActivite;
    private final int hauteurActivite;

    // Constructeur privé (singleton)
    private TailleComposants() {
        // Initialisation des tailles par défaut
        largeurActivite = 100;
        hauteurActivite = 60;

        // D'autres tailles pourront être ajoutées ici dans le futur
    }

    /**
     * Retourne l'instance unique de TailleComposants
     * @return l'instance de TailleComposants
     */
    public static TailleComposants getInstance() {
        return instance;
    }

    /**
     * Retourne la largeur par défaut d'une activité
     * @return la largeur en pixels
     */
    public int getLargeurActivite() {
        return largeurActivite;
    }

    /**
     * Retourne la hauteur par défaut d'une activité
     * @return la hauteur en pixels
     */
    public int getHauteurActivite() {
        return hauteurActivite;
    }
}
