package twisk.vues;

import javafx.scene.control.Label;
import javafx.scene.layout.VBox;
import javafx.scene.paint.Color;
import javafx.scene.shape.Circle;
import javafx.scene.shape.Rectangle;
import javafx.scene.layout.HBox;
import javafx.scene.layout.Pane;
import twisk.modele.ActiviteIG;
import twisk.modele.EtapeIG;
import twisk.modele.MondeIG;

public class VueActiviteIG extends VueEtapeIG {
    private Label titre;
    private Rectangle rectangle;
    private VBox conteneur;

    /**
     * Constructeur
     * @param etape l'étape à représenter
     * @param monde le monde auquel appartient l'étape
     */
    public VueActiviteIG(EtapeIG etape, MondeIG monde) {
        super(etape, monde);

        // Créer le rectangle représentant l'activité
        rectangle = new Rectangle(etape.getLargeur(), etape.getHauteur());

        // Créer le titre de l'activité
        titre = new Label(etape.getNom());
        titre.getStyleClass().add("titre-activite");
        titre.setPrefWidth(etape.getLargeur());

        // Créer la zone des clients
        Label zoneClients = new Label("Clients: 0");
        zoneClients.getStyleClass().add("zone-clients");
        zoneClients.setPrefWidth(etape.getLargeur());

        ActiviteIG activite = (ActiviteIG) etape;
        Label zoneParametres = new Label("Délai: " + activite.getDelai() + ", Écart: " + activite.getEcart());
        zoneParametres.getStyleClass().add("zone-parametres");
        zoneParametres.setPrefWidth(etape.getLargeur());

        // Créer un conteneur pour organiser les éléments
        conteneur = new VBox();
        conteneur.getChildren().addAll(titre, zoneClients, zoneParametres);
        conteneur.setPrefWidth(etape.getLargeur());
        conteneur.setPrefHeight(etape.getHauteur());

        // Ajouter les éléments à la vue
        this.getChildren().addAll(rectangle, conteneur);

        // Positionner la vue aux coordonnées de l'étape
        this.setLayoutX(etape.getPosX());
        this.setLayoutY(etape.getPosY());

        // Ajouter les classes CSS pour le styling
        this.getStyleClass().add("activite");
        rectangle.getStyleClass().add("activite-rectangle");

        // Mettre à jour le style en fonction de l'état de sélection
        mettreAJourStyle();
    }

    /**
     * Met à jour le style de l'étape en fonction de son état de sélection
     */
    @Override
    public void mettreAJourStyle() {
        if (monde.estSelectionnee(etape)) {
            // Style pour une étape sélectionnée
            this.getStyleClass().add("etape-selectionnee");
        } else {
            // Style pour une étape non sélectionnée
            this.getStyleClass().remove("etape-selectionnee");
        }

        // Vérifier si l'étape est une entrée ou une sortie
        if (monde.estUneEntree(etape.getIdentifiant())) {
            this.getStyleClass().add("etape-entree");
        } else {
            this.getStyleClass().remove("etape-entree");
        }

        if (monde.estUneSortie(etape.getIdentifiant())) {
            this.getStyleClass().add("etape-sortie");
        } else {
            this.getStyleClass().remove("etape-sortie");
        }
    }
}