package twisk.vues;

import javafx.scene.paint.Color;
import javafx.scene.shape.CubicCurve;
import javafx.scene.shape.Polygon;
import twisk.modele.ArcIG;
import twisk.modele.CourbeIG;
import twisk.modele.MondeIG;
import twisk.modele.PointDeControleIG;

/**
 * Vue représentant une courbe
 */
public class VueCourbeIG extends VueArcIG {
    private CubicCurve courbe;
    private Polygon fleche;

    /**
     * Constructeur
     * @param arc l'arc à représenter
     * @param monde le monde auquel appartient l'arc
     */
    public VueCourbeIG(ArcIG arc, MondeIG monde) {
        super(arc, monde);

        // Vérifier que l'arc est bien une courbe
        if (!(arc instanceof CourbeIG)) {
            throw new IllegalArgumentException("L'arc n'est pas une courbe");
        }

        CourbeIG courbeIG = (CourbeIG) arc;

        // Récupérer les points de contrôle
        PointDeControleIG p1 = arc.getP1();
        PointDeControleIG p2 = arc.getP2();

        // Créer la courbe
        courbe = new CubicCurve(
                p1.getPosX(), p1.getPosY(),
                courbeIG.getControlX1(), courbeIG.getControlY1(),
                courbeIG.getControlX2(), courbeIG.getControlY2(),
                p2.getPosX(), p2.getPosY()
        );
        courbe.setFill(null); // Pas de remplissage
        courbe.getStyleClass().add("arc-ligne");

        // Calculer l'angle de la tangente à la courbe au point d'arrivée
        double dx = p2.getPosX() - courbeIG.getControlX2();
        double dy = p2.getPosY() - courbeIG.getControlY2();
        double angle = Math.atan2(dy, dx);

        // Créer la flèche
        fleche = new Polygon();
        double size = 10; // Taille de la flèche

        // Calculer les points de la flèche
        double x1 = p2.getPosX() - size * Math.cos(angle);
        double y1 = p2.getPosY() - size * Math.sin(angle);
        double x2 = x1 - size * Math.cos(angle + Math.PI/6);
        double y2 = y1 - size * Math.sin(angle + Math.PI/6);
        double x3 = x1 - size * Math.cos(angle - Math.PI/6);
        double y3 = y1 - size * Math.sin(angle - Math.PI/6);

        // Définir les points de la flèche
        fleche.getPoints().add((double) p2.getPosX());
        fleche.getPoints().add((double) p2.getPosY());
        fleche.getPoints().add(x2);
        fleche.getPoints().add(y2);
        fleche.getPoints().add(x3);
        fleche.getPoints().add(y3);
        fleche.getStyleClass().add("arc-fleche");

        // Ajouter les éléments à la vue
        this.getChildren().addAll(courbe, fleche);

        // Maintenant que tout est initialisé, mettre à jour le style
        mettreAJourStyle();
    }

    /**
     * Met à jour le style de l'arc en fonction de son état de sélection
     */
    /**
     * Met à jour le style de l'arc en fonction de son état de sélection
     */
    @Override
    public void mettreAJourStyle() {
        if (monde.estSelectionne(arc)) {
            // Style pour un arc sélectionné
            courbe.setStroke(Color.valueOf("#ff6600"));
            courbe.setStrokeWidth(3);
            fleche.setFill(Color.valueOf("#ff6600"));
            fleche.setStroke(Color.valueOf("#ff6600"));
            this.getStyleClass().add("arc-selectionne");

            // Ajouter un effet de surbrillance
            courbe.setEffect(new javafx.scene.effect.DropShadow(5, Color.valueOf("#ff6600")));
            fleche.setEffect(new javafx.scene.effect.DropShadow(5, Color.valueOf("#ff6600")));
        } else {
            // Style pour un arc non sélectionné
            courbe.setStroke(Color.valueOf("#0066cc"));
            courbe.setStrokeWidth(2);
            fleche.setFill(Color.valueOf("#0066cc"));
            fleche.setStroke(Color.valueOf("#0066cc"));
            this.getStyleClass().remove("arc-selectionne");

            // Supprimer l'effet
            courbe.setEffect(null);
            fleche.setEffect(null);
        }
    }

}
