package twisk.vues;

import javafx.scene.SnapshotParameters;
import javafx.scene.image.WritableImage;
import javafx.scene.input.ClipboardContent;
import javafx.scene.input.Dragboard;
import javafx.scene.input.MouseEvent;
import javafx.scene.input.TransferMode;
import javafx.scene.layout.Pane;
import twisk.modele.EtapeIG;
import twisk.modele.MondeIG;

public abstract class VueEtapeIG extends Pane {
    protected final EtapeIG etape;
    protected final MondeIG monde;

    /**
     * Constructeur
     * @param etape l'étape à représenter
     * @param monde le monde auquel appartient l'étape
     */
    public VueEtapeIG(EtapeIG etape, MondeIG monde) {
        this.etape = etape;
        this.monde = monde;

        // Définir l'ID du composant avec l'identifiant de l'étape
        this.setId(etape.getIdentifiant());

        // Ajouter l'écouteur de clic pour la sélection
        this.setOnMouseClicked(event -> {
            monde.selectionnerEtape(etape);
            event.consume(); // Empêcher la propagation de l'événement
        });

        // Ajouter l'écouteur pour le début du drag
        this.setOnDragDetected(this::gererDebutDrag);
    }

    /**
     * Gère le début du drag d'une étape
     * @param event l'événement de souris
     */
    private void gererDebutDrag(MouseEvent event) {
        // Démarrer le drag and drop
        Dragboard db = this.startDragAndDrop(TransferMode.MOVE);

        // Créer le contenu du clipboard
        ClipboardContent content = new ClipboardContent();

        // Ajouter l'identifiant de l'étape au clipboard
        content.putString(etape.getIdentifiant());

        // Créer une image de l'étape pour visualiser le déplacement
        WritableImage snapshot = this.snapshot(new SnapshotParameters(), null);
        content.putImage(snapshot);

        // Définir le contenu du dragboard
        db.setContent(content);

        // Afficher l'identifiant pour vérification
        System.out.println("Début du drag de l'étape0: " + etape.getIdentifiant());

        // Consommer l'événement
        event.consume();
    }

    /**
     * Met à jour le style de l'étape en fonction de son état de sélection
     */
    public abstract void mettreAJourStyle();
}
