package twisk.vues;

import javafx.scene.paint.Color;
import javafx.scene.shape.Line;
import javafx.scene.shape.Polygon;
import twisk.modele.ArcIG;
import twisk.modele.LigneDroiteIG;
import twisk.modele.MondeIG;
import twisk.modele.PointDeControleIG;

/**
 * Vue représentant une ligne droite
 */
public class VueLigneDroiteIG extends VueArcIG {
    private Line ligne;
    private Polygon fleche;

    /**
     * Constructeur
     * @param arc l'arc à représenter
     * @param monde le monde auquel appartient l'arc
     */
    public VueLigneDroiteIG(ArcIG arc, MondeIG monde) {
        super(arc, monde);

        // Récupérer les points de contrôle
        PointDeControleIG p1 = arc.getP1();
        PointDeControleIG p2 = arc.getP2();

        // Créer la ligne
        ligne = new Line(p1.getPosX(), p1.getPosY(), p2.getPosX(), p2.getPosY());
        ligne.getStyleClass().add("arc-ligne");

        // Calculer l'angle de la ligne pour orienter la flèche
        double angle = Math.atan2(p2.getPosY() - p1.getPosY(), p2.getPosX() - p1.getPosX());

        // Créer la flèche
        fleche = new Polygon();
        double size = 10; // Taille de la flèche

        // Calculer les points de la flèche
        double x1 = p2.getPosX() - size * Math.cos(angle);
        double y1 = p2.getPosY() - size * Math.sin(angle);
        double x2 = x1 - size * Math.cos(angle + Math.PI/6);
        double y2 = y1 - size * Math.sin(angle + Math.PI/6);
        double x3 = x1 - size * Math.cos(angle - Math.PI/6);
        double y3 = y1 - size * Math.sin(angle - Math.PI/6);

        // Définir les points de la flèche
        fleche.getPoints().add((double) p2.getPosX());
        fleche.getPoints().add((double) p2.getPosY());
        fleche.getPoints().add(x2);
        fleche.getPoints().add(y2);
        fleche.getPoints().add(x3);
        fleche.getPoints().add(y3);
        fleche.getStyleClass().add("arc-fleche");

        // Ajouter les éléments à la vue
        this.getChildren().addAll(ligne, fleche);

        // Maintenant que tout est initialisé, mettre à jour le style
        mettreAJourStyle();
    }

    /**
     * Met à jour le style de l'arc en fonction de son état de sélection
     */
    /**
     * Met à jour le style de l'arc en fonction de son état de sélection
     */
    @Override
    public void mettreAJourStyle() {
        if (monde.estSelectionne(arc)) {
            // Style pour un arc sélectionné
            ligne.setStroke(Color.valueOf("#ff6600"));
            ligne.setStrokeWidth(3);
            fleche.setFill(Color.valueOf("#ff6600"));
            fleche.setStroke(Color.valueOf("#ff6600"));
            this.getStyleClass().add("arc-selectionne");

            // Ajouter un effet de surbrillance
            ligne.setEffect(new javafx.scene.effect.DropShadow(5, Color.valueOf("#ff6600")));
            fleche.setEffect(new javafx.scene.effect.DropShadow(5, Color.valueOf("#ff6600")));
        } else {
            // Style pour un arc non sélectionné
            ligne.setStroke(Color.valueOf("#0066cc"));
            ligne.setStrokeWidth(2);
            fleche.setFill(Color.valueOf("#0066cc"));
            fleche.setStroke(Color.valueOf("#0066cc"));
            this.getStyleClass().remove("arc-selectionne");

            // Supprimer l'effet
            ligne.setEffect(null);
            fleche.setEffect(null);
        }
    }

}
